import tkinter as tk
from tkinter import ttk
from tkinter.messagebox import showerror
from random import shuffle
from PIL import ImageTk, Image

# <zone non modificable>
def caracteristiques(marge, imwidth, imheight) :
    "renvoie les hauteurs en pixel des lignes horizontales"
    L, H = 11*marge+10*imwidth, 9*marge+6*imheight
    h1 = 2*marge+imheight
    h2 = 7*marge+5*imheight
    return L, H, h1, h2

def coord_carte(ligne, col, marge, imwidth, imheight) :
    """
    renvoie les coordonnées du coin en haut à gauche d'une carte

    imwidth, imheight : largeur et hauteur de l'image
    ligne, col : ligne et colonne où mettre le contour
    """
    L, H, h1, h2 = caracteristiques(marge, imwidth, imheight)
    if ligne == 0 :
        y = marge
    elif 1 <= ligne <= 4 :
        y = h1+marge + (ligne-1)*(marge+imheight)
    elif ligne == 5 :
        y = h2+marge
    x = (col+1)*(marge+imwidth) - imwidth
    if ligne == 6 : # case de transition
        x, y = L,H//2
    return x, y

def dessine_plateau(marge, imwidth, imheight, canvas) :
    "dessine le plateau de jeu"
    L, H, h1, h2 = caracteristiques(marge, imwidth, imheight)
    # zone ordinateur
    canvas.create_line(0,h1,L,h1)
    canvas.create_text(L+10, h1-10, text='Ordinateur', anchor='w', font=('TkMenuFont', 10), fill='black',angle=90)
    # zone joueur
    canvas.create_line(0,h2,L,h2)
    canvas.create_text(L+10, h2+h1-10, text='Mes cartes', anchor='w', font=('TkMenuFont', 10), fill='black',angle=90)

def initialisation() :
    """
    la fonction renvoie un tableau liste qui contient 6 tableaux, 1 tableau par ligne
    les deux tableaux à initialiser sont les tableaux 0 et 5 avec 10 cartes chacun.
    chaque tableau contient des entiers qui permettent de remonter au nom de l'image à afficher
    """
    liste = [[] for _ in range(8)]
    atirer = list(range(1, 104))
    shuffle(atirer)
    liste[0] = atirer[:10]
    liste[5] = atirer[10:20]
    liste[1].append(atirer[20])
    liste[2].append(atirer[21])
    liste[3].append(atirer[22])
    liste[4].append(atirer[23])
    for i in range(1,5) :
        liste[i] += [0,0,0,0,0]
    liste[6].append(0) # image du fond gris joueur
    liste[7].append(0) # image du fond gris ordi
    liste[5].sort() # les cartes du joueur sont triées
    for row in liste :
        print(row)
    return liste

def affiche(liste, canvas, images) :
    """
    liste = tableau de tableau
    liste[0] contient les cartes de la 1ère ligne, ...
    cf schéma pdf de présentation du projet
    """
    for row in liste :
        print(row)
    for ligne in range(6) :
        for colonne in range(len(liste[ligne])) :
            # print(ligne, colonne, MARGE+ligne*(MARGE+HEIGHT), MARGE+colonne*(MARGE+WIDTH))
            x, y = coord_carte(ligne, colonne, marge=MARGE, imwidth=WIDTH, imheight=HEIGHT)
            image = images[liste[ligne][colonne]]
            canvas.create_image(x, y, image=image, anchor='nw')
    # affichage de la case de transition joueur
    image = images[liste[6][0]]
    # print(image.name)
    canvas.create_image(640+50, 285+10, image=image, anchor='nw') # joueur
    # affichage de la case de transition ordi
    image = images[liste[7][0]]
    canvas.create_image(640+50, 285+10-80-10, image=image, anchor='nw') # ordi

def derniere_carte_non_nulle(liste, ligne) :
    """
    renvoie l'index de la dernière carte non nulle sur la ligne ligne
    """
    for j in range(6) :
            if liste[ligne][j] == 0 :
                j -= 1
                break
    return j

# </zone non modificable>

def choix(n, liste, score) :
    """
    on place la carte de valeur n
    dans le tableau liste
    et on met à jour le tableau score
    """
    ecarts = [0]*6

    return liste, score

def analyse(liste, canvas, images, score) :
    """
    analyse la carte jouée par le joueur et celle jouée par l'ordinateur
    la plus petite joue en premier
    liste : tableau de tableau des cartes
    score : tableau des scores 0: ordi, 1: joueur
    renvoie les tableaux liste et score mis à jours
    """
    # il faut utiliser la fonction choix

    # on affiche les changements
    affiche(liste, canvas, images)
    return liste, score

def ordinateur_choix(liste) :
    """
    choix de l'ordinateur dans liste[0]
    """
    return liste

def clic(event, liste, canvas, images, score, root):
    """
    Procédure principale
    event : évènement associé au clic de la souris
    WIDTH : largeur en pixels d'une image
    HEIGHT : hauteur en pixels d'une image
    MARGE : marge autour de l'image
    """
    ligne = event.y // (HEIGHT+MARGE) # numéro de la ligne cliquée
    colonne = event.x // (WIDTH+MARGE) # numéro de la colonne cliquée
    print(ligne, colonne)
    # liste[ligne][colonne] = numéro de l'image
    # images[liste[ligne][colonne]] est l'image correspondante
    if ligne == 5 :
        # le joueur joue
        # le joueur a cliqué sur la carte liste[ligne][colonne]
        pass
        # l'ordinateur joue
        liste = ordinateur_choix(liste)
        # on affiche les changements
        affiche(liste, canvas, images)


## Programme principal

# root window
root = tk.Tk()
root.title('6 qui prend')
root.geometry('800x600')

# liste des images
# la 1ère image (index 0) est le fond gris pour cacher les images retirées
images = [tk.PhotoImage(file='../img/fond_gris.gif')]
for i in range(1,105) :
    images.append(tk.PhotoImage(file=f'../img/{i}.gif'))

# on charge une image pour avoir ces caractéristiques
myimg = tk.PhotoImage(file='../img/jaune.gif')
WIDTH = myimg.width()
HEIGHT = myimg.height()
MARGE = 10
print('width', WIDTH)
print('height', HEIGHT)

canvas = tk.Canvas(root, width=800, height=600)
canvas.pack()
button = tk.Button(root, text="Place les cartes", fg="black", bg="gray")
button.place(x=640+15,y=285+100)
L, H, h1, h2 = caracteristiques(marge=MARGE, imwidth=WIDTH, imheight=HEIGHT)
scorej = tk.Label(root, text="0")
scorej.place(x=L+100,y=h2+MARGE+HEIGHT//2)
scoreo = tk.Label(root, text="0")
scoreo.place(x=L+100,y=h1-MARGE-HEIGHT//2)

score = [0]*2 # 0: ordi, 1: joueur
liste = initialisation()
canvas.bind('<Button-1>', lambda event : clic(event, liste, canvas, images, score, root))
button.bind('<Button-1>', lambda event : analyse(liste, canvas, images, score))
dessine_plateau(marge=MARGE, imwidth=WIDTH, imheight=HEIGHT, canvas=canvas)
affiche(liste, canvas, images)

root.mainloop() # start the app

